summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--utils/training/k_mixture_model.h13
1 files changed, 10 insertions, 3 deletions
diff --git a/utils/training/k_mixture_model.h b/utils/training/k_mixture_model.h
index af613f5..6b3a75d 100644
--- a/utils/training/k_mixture_model.h
+++ b/utils/training/k_mixture_model.h
@@ -124,11 +124,18 @@ typedef struct{
/* the total number of all W1,W2 word pair. */
guint32 m_WC;
/* the total number of instances of the word or phrases.
(two word phrase) */
- guint32 m_T; /* alias of m_WC, always the same. */
+ /* guint32 m_T; Please use m_WC instead.
+ alias of m_WC, always the same. */
+
/* n_r: the number of documents having exactly r occurrences. */
- guint32 m_n_0;
+ /* guint32 m_n_0;
+ Note: compute this value using the following equation.
+ m_n_0 = KMixtureModelMagicHeader.m_N - m_N_n_0;
+ m_N_n_0, the number of documents which contains the word or phrase.
+ (two word phrase) */
+ guint m_N_n_0;
guint32 m_n_1;
/* maximum instances of the word or phrase (two word phrase)
@@ -124,11 +124,18 @@ typedef struct{
/* the total number of all W1,W2 word pair. */
guint32 m_WC;
- /* the total number of instances of the word or phrases.
+ /* the total number of instances of the word or phrase.
(two word phrase) */